==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.asyncqueue;

import org.apache.geode.cache.wan.EventSequenceID;
import org.apache.geode.cache.wan.GatewayQueueEvent;

/**
 * Represents <code>Cache</code> events delivered to <code>AsyncEventListener</code>.
 *
 * @since GemFire 7.0
 */
public interface AsyncEvent<K, V> extends GatewayQueueEvent<K, V> {
  /**
   * Returns whether possibleDuplicate is set for this event.
   */
  boolean getPossibleDuplicate();

  /**
   * Returns the wrapper over the DistributedMembershipID, ThreadID, SequenceID which are used to
   * uniquely identify any region operation like create, update etc. This helps in sequencing the
   * events belonging to a unique producer. e.g. The EventID can be used to track events received by
   * <code>AsyncEventListener</code> to avoid processing duplicates.
   */
  EventSequenceID getEventSequenceID();
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/AsyncEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.asyncqueue;

import org.apache.geode.cache.wan.EventSequenceID;
import org.apache.geode.cache.wan.GatewayQueueEvent;

/**
 * Represents <code>Cache</code> events delivered to <code>AsyncEventListener</code>.
 *
 * @since GemFire 7.0
 */
public interface AsyncEvent<K, V> extends GatewayQueueEvent<K, V> {
  /**
   * Returns whether possibleDuplicate is set for this event.
   *
   * @return whether possibleDuplicate is set for this event
   */
  boolean getPossibleDuplicate();

  /**
   * Returns the wrapper over the DistributedMembershipID, ThreadID, SequenceID which are used to
   * uniquely identify any region operation like create, update etc. This helps in sequencing the
   * events belonging to a unique producer. e.g. The EventID can be used to track events received by
   * <code>AsyncEventListener</code> to avoid processing duplicates.
   *
   * @return the wrapper over the DistributedMembershipID, ThreadID, SequenceID which are used to
   *         uniquely identify any region operation
   */
  EventSequenceID getEventSequenceID();
}
